==> bitcream-smartsignage-custom-v0.6-16ba45.zip: backend/views/monitor/_datatable.php <==
<?php

use yii\helpers\Html;
use emberware\evidia\datatable\common\models\DataTableCustom;

?>
<div class="datatable">
        <?=
        DataTableCustom::widget([
            'dataProvider' => $dataProvider,
            'id' => 'monitor-table',
            // 'filterModel' => $filterModel,
            // 'searchProvider' => $searchProvider,
            'columns' => [
                ['attribute'=>Yii::t('smartsignage', 'Name'),
                    'format'=>'raw',
                    'value' => function($data)
                    {return Html::a($data->name, [Yii::$app->controller->id.'/update','id'=>$data->id]);}
                ],
                ['attribute'=>Yii::t('smartsignage', 'Preset'),
                    'format'=>'raw',
                    'value' => function($data)
                    {return Html::a($data->basePreset->name, ['preset/update','id'=>$data->base_preset_id]);}
                ],
                [
                    'class' => '\yii\grid\ActionColumn',
                    'header' => Yii::t('smartsignage', 'Actions'),
                    'visibleButtons' => [ 'delete' => function($data){
                                                if(Yii::$app->user->can("admin")){ 
                                                    return true;
                                                }else{
                                                    return false;
                                                }
                                           },
                                          'update' => false, 
                                          'view' => false],
                ]
            ],
            'clientOptions' => [
                "responsive"=>true,
                "language" => [
                    "url" => Yii::t('smartsignage',"//cdn.datatables.net/plug-ins/9dcbecd42ad/i18n/English.json")
                ]
            ]
        ]);
    ?>
</div>

==> bitcream-smartsignage-custom-v0.7.1-31692a.zip: backend/views/monitor/_datatable.php <==
<?php

use yii\helpers\Html;
use emberware\evidia\datatable\common\models\DataTableCustom;

?>
<div class="datatable">
        <?=
        DataTableCustom::widget([
            'dataProvider' => $dataProvider,
            'id' => 'monitor-table',
            // 'filterModel' => $filterModel,
            // 'searchProvider' => $searchProvider,
            'columns' => [
                ['attribute'=>Yii::t('smartsignage', 'Name'),
                    'format'=>'raw',
                    'value' => function($data)
                    {return Html::a($data->name, [Yii::$app->controller->id.'/update','id'=>$data->id]);}
                ],
                ['attribute'=>Yii::t('smartsignage', 'Preset'),
                    'format'=>'raw',
                    'value' => function($data)
                    {return Html::a($data->basePreset->name, ['preset/update','id'=>$data->base_preset_id, 'monitor' => $data->id]);}
                ],
                [
                    'class' => '\yii\grid\ActionColumn',
                    'header' => Yii::t('smartsignage', 'Actions'),
                    'visibleButtons' => [ 'delete' => function($data){
                                                if(Yii::$app->user->can("admin")){ 
                                                    return true;
                                                }else{
                                                    return false;
                                                }
                                           },
                                          'update' => false, 
                                          'view' => false],
                ]
            ],
            'clientOptions' => [
                "responsive"=>true,
                "language" => [
                    "url" => Yii::t('smartsignage',"//cdn.datatables.net/plug-ins/9dcbecd42ad/i18n/English.json")
                ]
            ]
        ]);
    ?>
</div>
